runner

package
v0.6.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunInteractiveTaskSelector

func RunInteractiveTaskSelector(tasks []config.Task) (*config.Task, error)

RunInteractiveTaskSelector runs the interactive task selector and returns the selected task

Types

type TaskFinder

type TaskFinder struct{}

TaskFinder helps find tasks by name from a list

func NewTaskFinder

func NewTaskFinder() *TaskFinder

NewTaskFinder creates a new task finder

func (*TaskFinder) FindTask

func (tf *TaskFinder) FindTask(taskName string, tasks []*config.Task) (*config.Task, error)

FindTask searches for a task by name in the given list

type TaskRunner

type TaskRunner struct {
	// contains filtered or unexported fields
}

TaskRunner handles execution of tasks

func NewTaskRunner

func NewTaskRunner(verbose bool) *TaskRunner

NewTaskRunner creates a new task runner

func NewTaskRunnerWithOptions

func NewTaskRunnerWithOptions(verbose bool, projectRoot string, paranoidMode bool) *TaskRunner

NewTaskRunnerWithOptions creates a new task runner with all options

func NewTaskRunnerWithProjectRoot

func NewTaskRunnerWithProjectRoot(verbose bool, projectRoot string) *TaskRunner

NewTaskRunnerWithProjectRoot creates a new task runner with a specific project root

func (*TaskRunner) RunTask

func (tr *TaskRunner) RunTask(task *config.Task) error

RunTask executes a given task with proper environment and working directory setup

type TaskSelectorModel

type TaskSelectorModel struct {
	// contains filtered or unexported fields
}

TaskSelectorModel represents the Bubble Tea model for task selection

func NewTaskSelectorModel

func NewTaskSelectorModel(tasks []config.Task) *TaskSelectorModel

NewTaskSelectorModel creates a new task selector model

func (*TaskSelectorModel) Init

func (m *TaskSelectorModel) Init() tea.Cmd

Init implements the tea.Model interface

func (*TaskSelectorModel) Update

func (m *TaskSelectorModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update implements the tea.Model interface

func (*TaskSelectorModel) View

func (m *TaskSelectorModel) View() string

View implements the tea.Model interface

Jump to