Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TaskRunner ¶
type TaskRunner struct {
// contains filtered or unexported fields
}
TaskRunner handles execution of tasks
func NewTaskRunner ¶
func NewTaskRunner(verbose bool) *TaskRunner
NewTaskRunner creates a new task runner
func NewTaskRunnerWithOptions ¶
func NewTaskRunnerWithOptions(verbose bool, projectRoot string, paranoidMode bool) *TaskRunner
NewTaskRunnerWithOptions creates a new task runner with all options
func NewTaskRunnerWithProjectRoot ¶
func NewTaskRunnerWithProjectRoot(verbose bool, projectRoot string) *TaskRunner
NewTaskRunnerWithProjectRoot creates a new task runner with a specific project root
type TaskSelectorModel ¶
type TaskSelectorModel struct {
// contains filtered or unexported fields
}
TaskSelectorModel represents the Bubble Tea model for task selection
func NewTaskSelectorModel ¶
func NewTaskSelectorModel(tasks []config.Task) *TaskSelectorModel
NewTaskSelectorModel creates a new task selector model
func (*TaskSelectorModel) Init ¶
func (m *TaskSelectorModel) Init() tea.Cmd
Init implements the tea.Model interface
func (*TaskSelectorModel) View ¶
func (m *TaskSelectorModel) View() string
View implements the tea.Model interface
Click to show internal directories.
Click to hide internal directories.